Data

Enum Data 

pub enum Data<'ty, 'r> {
    Owned(Box<dyn ShareableTid<'ty>>),
    Borrowed(&'r dyn ShareableTid<'ty>),
    Mut(&'r mut dyn ShareableTid<'ty>),
}
Stored value variants inside a Context.

Values may be owned, immutably borrowed, or mutably borrowed.

Variants



Owned(Box<dyn ShareableTid<'ty>>)



Borrowed(&'r dyn ShareableTid<'ty>)



Mut(&'r mut dyn ShareableTid<'ty>)

Implementations

Source

impl<'ty, 'r> Data<'ty, 'r>

pub fn downcast_ref<'b, T: Tid<'ty>>(&'b self) -> Option<&'b T>

Downcast to a shared reference of the underlying value.

pub fn downcast_mut<'b, T: Tid<'ty>>(&'b mut self) -> Option<&'b mut T>

Downcast to a mutable reference of the underlying value.

pub fn into_owned<T: Clone + Tid<'ty>>(self) -> Result<T, Self>

Convert into an owned value.

Borrowed values are cloned. Returns Err(self) when the type does not match.

pub fn try_take_owned<T: Tid<'ty>>(self) -> Result<T, Self>

Take the owned value if present.

Borrowed variants return Err(self).