Context

Struct Context 

pub struct Context<'ty, 'r> { /* private fields */ }
Runtime context storing values by type.

The context can store owned values as well as borrowed references (immutable or mutable). Values are keyed by TypeId using a specialized hasher for fast lookups.

Implementations

Source

impl<'ty, 'r> Context<'ty, 'r>

pub fn new() -> Self

Create a new empty Context.

pub fn insert_unchecked(&mut self, key: TypeId, data: Data<'ty, 'r>)

Insert a value into the context without checking the type.

This is a low-level escape hatch for advanced use-cases.

pub fn insert_ref<T: ShareableTid<'ty>>(&mut self, value: &'r T)

Insert a borrowed value into the context.

pub fn insert_mut<T: ShareableTid<'ty>>(&mut self, value: &'r mut T)

Insert a mutable reference into the context.

pub fn insert<T: ShareableTid<'ty>>(&mut self, value: T)

Insert an owned value into the context.

pub fn get<'b, T: ShareableTid<'ty>>(&'b self) -> Option<&'b T>

Get a shared reference to a stored value by type.

pub fn get_mut<'b, T: ShareableTid<'ty>>(&'b mut self) -> Option<&'b mut T>

Get a mutable reference to a stored value by type.

pub fn get_data<'b>(&'b self, id: &TypeId) -> Option<&'b Data<'ty, 'r>>

Get a stored Data by TypeId.

pub fn get_data_mut<'b>( &'b mut self, id: &TypeId, ) -> Option<&'b mut Data<'ty, 'r>>

Get a mutable Data by TypeId.

pub fn get_disjoint_mut<'b, const N: usize>( &'b mut self, keys: [&TypeId; N], ) -> [Option<&'b mut Data<'ty, 'r>>; N]

Get multiple mutable Data entries by distinct TypeIds.

pub fn take<T: ShareableTid<'ty>>(&mut self) -> Option<T>

Remove an owned value from the context and return it.

pub fn remove<T: ShareableTid<'ty>>(&mut self) -> Option<Data<'ty, 'r>>

Remove any stored value for the given type and return the raw Data.

pub fn contains<T: ShareableTid<'ty>>(&self) -> bool

Check if a value of a specific type is present.

pub fn clear(&mut self)

Clear all values from the context.